/// <reference types="node" />
import { TankStatus } from './status';
export declare class Tank {
    /**
     * ID do tanque.
     * @readonly
     */
    readonly id: number;
    /**
     * ID do produto.
     * @readonly
     */
    readonly productCode: string;
    /**
     * Status do tanque.
     * @readonly
     */
    readonly status: TankStatus;
    /**
     * Quantidade de campos com dados (exemplo: volume, tc-volume, água, etc).
     * @readonly
     */
    readonly dataFieldsLength: number;
    /**
     * Volume de combustível no tanque.
     * @readonly
     */
    readonly volume: number;
    /**
     * Volume de combustível no tanque (considerando a temperatura).
     * @readonly
     */
    readonly tcVolume: number;
    /**
     * Volume vazio no tanque.
     * @readonly
     */
    readonly ullage: number;
    /**
     * Altura do tanque.
     * @readonly
     */
    readonly height: number;
    /**
     * Quantidade de água no tanque.
     * @readonly
     */
    readonly water: number;
    /**
     * Temperatura no tanque.
     * @readonly
     */
    readonly temperature: number;
    /**
     * Volume de água no tanque.
     * @readonly
     */
    readonly waterVolume: number;
    constructor(id: number, productCode: string, status: TankStatus, dataFieldsLength: number, volume: number, tcVolume: number, ullage: number, height: number, water: number, temperature: number, waterVolume: number);
    /**
     * Cria instância de um tanque através dos bytes retornados pelo TLS.
     * @param buffer Buffer contendo informações do tanque
     * @returns Tanque com as informações tratadas.
     */
    static fromBytes(buffer: Buffer): Tank;
}
